@@ -123,7 +123,7 @@ def init(
         # Generate password hash
         try:
             password_hash = subprocess.run(
-                ["htpasswd", "-nb", user, password], stdout=subprocess.PIPE
+                ["htpasswd", "-nbB", user, password], stdout=subprocess.PIPE
             )
             backplane_config["password_hash"] = (
                 password_hash.stdout.rstrip().decode().split(":")[1]
@@ -290,6 +290,7 @@ def down(
 def install(
     name: str = typer.Argument(os.path.basename(os.getcwd())),
     path: Path = typer.Argument(os.getcwd()),
+    source: str = typer.Option(None, "--from", "-f"),
 ):
     """
     Install an app into backplane.
@@ -302,8 +303,15 @@ def install(
             fg=typer.colors.BRIGHT_BLACK,
         )
 
-    app = App(name=name, path=path, config=conf)
-    app.install()
+    app = App(name=name, path=path, source=source, config=conf)
+    try:
+        app.install()
+    except Exception as e:
+        typer.secho(
+            f"Failed to install {name} from {path}: {e}",
+            err=True,
+            fg=typer.colors.RED,
+        )
 
 
 @app.command()
@@ -342,18 +350,18 @@ def status(
 def version_callback(value: bool):
     if value:
         version = read_version(".", "__init__.py")
-        typer.echo(f"backplane CLI: {version}")
+        typer.echo(f"{version}")
         raise typer.Exit()
 
 
 def checkPrerequisites(ctx):
     # Check for Docker
-    if not which("docker"):
-        if ctx.invoked_subcommand == "init":
-            pass
-        else:
-            typer.secho("Docker not installed", err=True, fg=typer.colors.RED)
-            raise typer.Abort()
+    # if not which("docker"):
+    #     if ctx.invoked_subcommand == "init":
+    #         pass
+    #     else:
+    #         typer.secho("Docker not installed", err=True, fg=typer.colors.RED)
+    #         raise typer.Abort()
 
     if not os.path.exists(conf.config_dir):
         if ctx.invoked_subcommand == "init":
