@@ -34,7 +34,9 @@ def createNetwork(network: str):
     backplane_network_exists = False
 
     try:
+        print(os.getenv("DOCKER_HOST"))
         docker_client = docker.from_env()
+        print(docker_client)
         docker_networks = docker_client.networks.list(names=network)
 
         for docker_network in docker_networks:
@@ -148,7 +150,7 @@ def getDynamicDomain(environment: str = "sss"):
             f = requests.request("GET", "https://ifconfig.me")
             ip = f.text.replace(".", "-")
 
-            domain = f"{ip}.nip.io"
+            domain = f"{ip}.ns0.co"
         except Exception as e:
             typer.secho(
                 f"Couldn't determine dynamic domain: {e}",
